@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008-2012 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008-2011 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -16,7 +16,7 @@
 #
 #  You should have received a copy of the GNU General Public License
 #  along with Shutter; if not, write to the Free Software
-#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 ###################################################
 
@@ -251,7 +251,7 @@ sub fct_ret_edit_menu {
 	$self->{_menu_edit}->append( Gtk2::SeparatorMenuItem->new );
 
 	$self->{_menuitem_settings} = Gtk2::ImageMenuItem->new_from_stock('gtk-preferences');
-	$self->{_menuitem_settings}->add_accelerator( 'activate', $accel_group, Gtk2::Gdk->keyval_from_name('P'), qw/mod1-mask/, qw/visible/ );
+	$self->{_menuitem_settings}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{P}, qw/mod1-mask/, qw/visible/ );
 	$self->{_menu_edit}->append( $self->{_menuitem_settings} );
 
 	return $self->{_menu_edit};
@@ -319,21 +319,21 @@ sub fct_ret_session_menu {
 	$self->{_menu_session} = Gtk2::Menu->new();
 
 	$self->{_menuitem_back} = Gtk2::ImageMenuItem->new_from_stock('gtk-go-back');
-	$self->{_menuitem_back}->add_accelerator( 'activate', $accel_group, Gtk2::Gdk->keyval_from_name('Left'), qw/mod1-mask/, qw/visible/ );
+	$self->{_menuitem_back}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{Left}, qw/mod1-mask/, qw/visible/ );
 	$self->{_menu_session}->append( $self->{_menuitem_back} );
 
 	$self->{_menuitem_forward} = Gtk2::ImageMenuItem->new_from_stock('gtk-go-forward');
-	$self->{_menuitem_forward}->add_accelerator( 'activate', $accel_group, Gtk2::Gdk->keyval_from_name('Right'), qw/mod1-mask/, qw/visible/ );
+	$self->{_menuitem_forward}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{Right}, qw/mod1-mask/, qw/visible/ );
 	$self->{_menu_session}->append( $self->{_menuitem_forward} );
 
 	$self->{_menu_session}->append( Gtk2::SeparatorMenuItem->new );
 
 	$self->{_menuitem_first} = Gtk2::ImageMenuItem->new_from_stock('gtk-goto-first');
-	$self->{_menuitem_first}->add_accelerator( 'activate', $accel_group, Gtk2::Gdk->keyval_from_name('Home'), qw/mod1-mask/, qw/visible/ );
+	$self->{_menuitem_first}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{Home}, qw/mod1-mask/, qw/visible/ );
 	$self->{_menu_session}->append( $self->{_menuitem_first} );
 
 	$self->{_menuitem_last} = Gtk2::ImageMenuItem->new_from_stock('gtk-goto-last');
-	$self->{_menuitem_last}->add_accelerator( 'activate', $accel_group, Gtk2::Gdk->keyval_from_name('End'), qw/mod1-mask/, qw/visible/ );
+	$self->{_menuitem_last}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{End}, qw/mod1-mask/, qw/visible/ );
 	$self->{_menu_session}->append( $self->{_menuitem_last} );
 	
 	return $self->{_menu_session};
@@ -398,7 +398,7 @@ sub fct_ret_help_menu {
 	$self->{_menu_help}->append( Gtk2::SeparatorMenuItem->new );
 
 	$self->{_menuitem_about} = Gtk2::ImageMenuItem->new_from_stock('gtk-about');
-	$self->{_menuitem_about}->add_accelerator( 'activate', $accel_group, Gtk2::Gdk->keyval_from_name('I'), qw/control-mask/, qw/visible/ );
+	$self->{_menuitem_about}->add_accelerator( 'activate', $accel_group, $Gtk2::Gdk::Keysyms{I}, qw/control-mask/, qw/visible/ );
 	$self->{_menu_help}->append( $self->{_menuitem_about} );
 
 	return $self->{_menu_help};
@@ -580,20 +580,23 @@ sub fct_ret_actions_menu{
 	
 	$self->{_menu_actions} = Gtk2::Menu->new();
 
+	#~ $self->{_menuitem_reopen_default} = Gtk2::ImageMenuItem->new_with_mnemonic( 
+			#~ sprintf( $d->get('_Open with %s'), ''),
+ 		#~ );
+	$self->{_menuitem_reopen_default} = Gtk2::ImageMenuItem->new_with_mnemonic( 
+			$d->get('_Open with default application')
+ 		);
+	$self->{_menuitem_reopen_default}->set_image( Gtk2::Image->new_from_stock( 'gtk-open', 'menu' ) );
+	$self->{_menuitem_reopen_default}->set_sensitive(FALSE);
+	$self->{_menuitem_reopen_default}->set_name('item-reopen-default');
+	$self->{_menu_actions}->append( $self->{_menuitem_reopen_default} );
+
 	$self->{_menuitem_reopen} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Open wit_h') );
 	$self->{_menuitem_reopen}->set_image( Gtk2::Image->new_from_stock( 'gtk-open', 'menu' ) );
 	$self->{_menuitem_reopen}->set_sensitive(FALSE);
 	$self->{_menuitem_reopen}->set_name('item-reopen-list');
 	$self->{_menu_actions}->append( $self->{_menuitem_reopen} );
 
-	$self->{_menuitem_show_in_folder} = Gtk2::ImageMenuItem->new_with_mnemonic( 
-			$d->get('Show in _folder')
- 		);
-	$self->{_menuitem_show_in_folder}->set_image( Gtk2::Image->new_from_stock( 'gtk-open', 'menu' ) );
-	$self->{_menuitem_show_in_folder}->set_sensitive(FALSE);
-	$self->{_menuitem_show_in_folder}->set_name('item-reopen-default');
-	$self->{_menu_actions}->append( $self->{_menuitem_show_in_folder} );
-
 	$self->{_menuitem_rename} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Rename...') );
 	$self->{_menuitem_rename}->add_accelerator( 'activate', $accel_group, Gtk2::Accelerator->parse('F2'), qw/visible/ ) if $accel_group;
 	$self->{_menuitem_rename}->set_image( Gtk2::Image->new_from_stock( 'gtk-edit', 'menu' ) );
@@ -677,20 +680,23 @@ sub fct_ret_actions_menu_large{
 	
 	$self->{_menu_large_actions} = Gtk2::Menu->new();
 
+	#~ $self->{_menuitem_large_reopen_default} = Gtk2::ImageMenuItem->new_with_mnemonic( 
+			#~ sprintf( $d->get('_Open with %s'), ''),
+ 		#~ );
+	$self->{_menuitem_large_reopen_default} = Gtk2::ImageMenuItem->new_with_mnemonic( 
+			$d->get('_Open with default application')
+ 		);
+	$self->{_menuitem_large_reopen_default}->set_image( Gtk2::Image->new_from_stock( 'gtk-open', 'menu' ) );
+	$self->{_menuitem_large_reopen_default}->set_sensitive(FALSE);
+	$self->{_menuitem_large_reopen_default}->set_name('item-large-reopen-default');
+	$self->{_menu_large_actions}->append( $self->{_menuitem_large_reopen_default} );
+
 	$self->{_menuitem_large_reopen} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('Open wit_h') );
 	$self->{_menuitem_large_reopen}->set_image( Gtk2::Image->new_from_stock( 'gtk-open', 'menu' ) );
 	$self->{_menuitem_large_reopen}->set_sensitive(FALSE);
 	$self->{_menuitem_large_reopen}->set_name('item-large-reopen-list');
 	$self->{_menu_large_actions}->append( $self->{_menuitem_large_reopen} );
 
-	$self->{_menuitem_large_show_in_folder} = Gtk2::ImageMenuItem->new_with_mnemonic( 
-			$d->get('Show in _folder')
- 		);
-	$self->{_menuitem_large_show_in_folder}->set_image( Gtk2::Image->new_from_stock( 'gtk-open', 'menu' ) );
-	$self->{_menuitem_large_show_in_folder}->set_sensitive(FALSE);
-	$self->{_menuitem_large_show_in_folder}->set_name('item-reopen-default');
-	$self->{_menu_large_actions}->append( $self->{_menuitem_large_show_in_folder} );
-
 	$self->{_menuitem_large_rename} = Gtk2::ImageMenuItem->new_with_mnemonic( $d->get('_Rename...') );
 	$self->{_menuitem_large_rename}->set_image( Gtk2::Image->new_from_stock( 'gtk-edit', 'menu' ) );
 	$self->{_menuitem_large_rename}->set_sensitive(FALSE);
