@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008-2012 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008-2011 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -16,7 +16,7 @@
 #
 #  You should have received a copy of the GNU General Public License
 #  along with Shutter; if not, write to the Free Software
-#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 ###################################################
 
@@ -195,7 +195,7 @@ sub select_simple {
 				if ( $event->type eq 'key-press' ) {
 										
 					#toggle zoom window
-					if ( $event->keyval == Gtk2::Gdk->keyval_from_name('space') ) {
+					if ( $event->keyval == $Gtk2::Gdk::Keysyms{space} ) {
 						if ($self->{_zoom_active}){
 							$zoom_window->hide_all;
 							$self->{_zoom_active} = FALSE;
@@ -206,7 +206,7 @@ sub select_simple {
 					}
 						
 					#quit on escape
-					if ( $event->keyval == Gtk2::Gdk->keyval_from_name('Escape') ) {
+					if ( $event->keyval == $Gtk2::Gdk::Keysyms{Escape} ) {
 						if ( $rect_w > 1 ) {
 							#clear the last rectangle
 							$self->{_root}->draw_rectangle( $gc, 0, $rect_x, $rect_y, $rect_w, $rect_h );
