@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008-2012 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008-2011 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -16,7 +16,7 @@
 #
 #  You should have received a copy of the GNU General Public License
 #  along with Shutter; if not, write to the Free Software
-#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 ###################################################
 
@@ -80,35 +80,38 @@ sub new {
 		if($compos){
 			$self->{_highlighter}->set_colormap($self->{_main_gtk_window}->get_screen->get_rgba_colormap);
 		}
-
-		$self->{_highlighter}->set_app_paintable(TRUE);
-		$self->{_highlighter}->set_decorated(FALSE);
+	
+		$self->{_highlighter}->double_buffered(FALSE);
+	    $self->{_highlighter}->set_app_paintable(TRUE);
+	    $self->{_highlighter}->set_decorated(FALSE);
 		$self->{_highlighter}->set_skip_taskbar_hint(TRUE);
 		$self->{_highlighter}->set_skip_pager_hint(TRUE);	    
-		$self->{_highlighter}->set_keep_above(TRUE);
-		$self->{_highlighter}->set_accept_focus(FALSE);
+	    $self->{_highlighter}->set_keep_above(TRUE);
+	    $self->{_highlighter}->set_accept_focus(FALSE);
+	    $self->{_highlighter}->set_sensitive(FALSE);
 
 		#obtain current colors and font_desc from the main window
-		my $style = $self->{_main_gtk_window}->get_style;
-		my $sel_bg = $style->bg('selected');
-		my $sel_tx = $style->text('selected');
-		my $font_fam = $style->font_desc->get_family;
-		my $font_size = $style->font_desc->get_size / Gtk2::Pango->scale;
-		
-		#get current monitor
-		my $mon = $self->get_current_monitor;
+	    my $style 		= $self->{_main_gtk_window}->get_style;
+		my $sel_bg 		= $style->bg('selected');
+		my $sel_tx 		= $style->text('selected');
+		my $font_fam 	= $style->font_desc->get_family;
+		my $font_size 	= $style->font_desc->get_size / Gtk2::Pango->scale;
+
+		my $mon 	= $self->get_current_monitor;
+		#~ my $font_size 	= int( $mon->width * 0.007 );
+		#~ my $font_size2 	= int( $mon->width * 0.006 );
 
 		$self->{_highlighter_expose} = $self->{_highlighter}->signal_connect('expose-event' => sub{
+			#remove old handler
+			if(defined $self->{_highlighter_anim}){
+				my $removed = Glib::Source->remove($self->{_highlighter_anim});
+			}
 
 			return FALSE unless $self->{_highlighter}->window;
 
-			#Place window and resize it
-			$self->{_highlighter}->window->move_resize($self->{_c}{'cw'}{'x'}-3, $self->{_c}{'cw'}{'y'}-3 ,$self->{_c}{'cw'}{'width'}+6, $self->{_c}{'cw'}{'height'}+6);			
-			
 			print $self->{_c}{'cw'}{'window'}->get_name, "\n" if $self->{_sc}->get_debug; 
 
 			my $text = Glib::Markup::escape_text ($self->{_c}{'cw'}{'window'}->get_name);
-			utf8::decode $text;
 			
 			my $sec_text =  "\n".$self->{_c}{'cw'}{'width'} . "x" . $self->{_c}{'cw'}{'height'};
 
@@ -119,15 +122,6 @@ sub new {
 			#app icon
 			my $icon = $self->{_c}{'cw'}{'window'}->get_icon;
 			
-			#create cairo context
-			my $cr = Gtk2::Gdk::Cairo::Context->create ($self->{_highlighter}->window);
-			
-			#pango layout
-			my $layout = Gtk2::Pango::Cairo::create_layout($cr);
-			$layout->set_width( ($w - $icon->get_width - $font_size * 3) * Gtk2::Pango->scale );
-			$layout->set_alignment('left');
-			$layout->set_wrap('char');
-
 			#warning if there are no subwindows
 			#when we are in section mode and 
 			#a toplevel window was already selected
@@ -141,11 +135,17 @@ sub new {
 					my $d = $self->{_sc}->get_gettext;
 					$text = $d->get("No subwindow detected");
 					$sec_text = "\n".$d->get("Maybe this window is using client-side windows (or similar).\nShutter is not yet able to query the tree information of such windows.");
-					
-					#wrap nicely
-					$layout->set_wrap('word-char');
 				}
 			}
+	
+			#create cairo context
+			my $cr = Gtk2::Gdk::Cairo::Context->create ($self->{_highlighter}->window);
+
+			#pango layout
+			my $layout = Gtk2::Pango::Cairo::create_layout($cr);
+			$layout->set_width( ($w - $icon->get_width - $font_size * 3) * Gtk2::Pango->scale );
+			$layout->set_alignment('left');
+			$layout->set_wrap('char');
 			
 			#set text
 			$layout->set_markup("<span font_desc=\"$font_fam $font_size\" weight=\"bold\" foreground=\"#FFFFFF\">$text</span><span font_desc=\"$font_fam $font_size\" foreground=\"#FFFFFF\">$sec_text</span>");
@@ -167,54 +167,72 @@ sub new {
 			#two different ways - compositing or not
 			if($compos){
 				
-				#fill window
-				$cr->set_operator('source');
-				$cr->set_source_rgba( $sel_bg->red / 257 / 255, $sel_bg->green / 257 / 255, $sel_bg->blue / 257 / 255, 0.3 );
-				$cr->paint;
-
-				#Parent window with text and icon			
-				if($self->{_c}{'cw'}{'is_parent'}){						
+				my $counter = 0;
+				$self->{_highlighter_anim} = Glib::Timeout->add (20, sub{
 					
-					$cr->set_operator('over');
-																			
-					#create small frame (window outlines)
-					$cr->set_source_rgba( $sel_bg->red / 257 / 255, $sel_bg->green / 257 / 255, $sel_bg->blue / 257 / 255, 0.75 );
-					$cr->set_line_width(6);
-					$cr->rectangle (0, 0, $w, $h);
-					$cr->stroke;
-					
-					if($lw <= $w && $lh <= $h){
-					
-						#rounded rectangle to display the window name
-						$cr->move_to( $xi + $ri, $yi );
-						$cr->line_to( $xi + $wi - $ri, $yi );
-						$cr->curve_to( $xi + $wi, $yi, $xi + $wi, $yi, $xi + $wi, $yi + $ri );
-						$cr->line_to( $xi + $wi, $yi + $hi - $ri );
-						$cr->curve_to( $xi + $wi, $yi + $hi, $xi + $wi, $yi + $hi, $xi + $wi - $ri, $yi + $hi );
-						$cr->line_to( $xi + $ri, $yi + $hi );
-						$cr->curve_to( $xi, $yi + $hi, $xi, $yi + $hi, $xi, $yi + $hi - $ri );
-						$cr->line_to( $xi, $yi + $ri );
-						$cr->curve_to( $xi, $yi, $xi, $yi, $xi + $ri, $yi );
-						$cr->fill;	
-
-						#app icon
-						Gtk2::Gdk::Cairo::Context::set_source_pixbuf( $cr, $icon, $xi + $font_size, $yi + $font_size );
-						$cr->paint;
+						return FALSE unless $self->{_highlighter}->window;
 						
-						#draw the pango layout
-						$cr->move_to( $xi + $font_size*2 + $icon->get_width, $yi + $font_size );
-						Gtk2::Pango::Cairo::show_layout( $cr, $layout );	
+						#increase animation counter
+						$counter++;
+													
+						#fill window
+						$cr->set_operator('source');
+						$cr->set_source_rgba( $sel_bg->red / 257 / 255, $sel_bg->green / 257 / 255, $sel_bg->blue / 257 / 255, $counter * 0.02 );
+						$cr->paint;
+	
+						#Parent window with text and icon			
+						if($self->{_c}{'cw'}{'is_parent'}){						
+							
+							$cr->set_operator('over');
+																					
+							#create small frame (window outlines)
+							$cr->set_source_rgba( $sel_bg->red / 257 / 255, $sel_bg->green / 257 / 255, $sel_bg->blue / 257 / 255, 0.75 );
+							$cr->set_line_width(6);
+							$cr->rectangle (0, 0, $w, $h);
+							$cr->stroke;
+							
+							if($lw <= $w && $lh <= $h){
+							
+								#rounded rectangle to display the window name
+								$cr->move_to( $xi + $ri, $yi );
+								$cr->line_to( $xi + $wi - $ri, $yi );
+								$cr->curve_to( $xi + $wi, $yi, $xi + $wi, $yi, $xi + $wi, $yi + $ri );
+								$cr->line_to( $xi + $wi, $yi + $hi - $ri );
+								$cr->curve_to( $xi + $wi, $yi + $hi, $xi + $wi, $yi + $hi, $xi + $wi - $ri, $yi + $hi );
+								$cr->line_to( $xi + $ri, $yi + $hi );
+								$cr->curve_to( $xi, $yi + $hi, $xi, $yi + $hi, $xi, $yi + $hi - $ri );
+								$cr->line_to( $xi, $yi + $ri );
+								$cr->curve_to( $xi, $yi, $xi, $yi, $xi + $ri, $yi );
+								$cr->fill;	
+	
+								#app icon
+								Gtk2::Gdk::Cairo::Context::set_source_pixbuf( $cr, $icon, $xi + $font_size, $yi + $font_size );
+								$cr->paint;
+								
+								#draw the pango layout
+								$cr->move_to( $xi + $font_size*2 + $icon->get_width, $yi + $font_size );
+								Gtk2::Pango::Cairo::show_layout( $cr, $layout );	
 
+							}
+
+						}else{
+							#create small frame
+							$cr->set_source_rgba( $sel_bg->red / 257 / 255, $sel_bg->green / 257 / 255, $sel_bg->blue / 257 / 255, 0.75 );
+							$cr->set_line_width(6);
+							$cr->rectangle (0, 0, $w, $h);
+							$cr->stroke;	
+						}
+							
+					#quit animation	
+					if($counter == 15){
+						return FALSE;
+					}else{
+						return TRUE;	
 					}
-
-				}else{
-					#create small frame
-					$cr->set_source_rgba( $sel_bg->red / 257 / 255, $sel_bg->green / 257 / 255, $sel_bg->blue / 257 / 255, 0.75 );
-					$cr->set_line_width(6);
-					$cr->rectangle (0, 0, $w, $h);
-					$cr->stroke;	
-				}
-
+	
+					return FALSE;	
+				});	
+			
 			#no compositing
 			}else{
 
@@ -285,26 +303,22 @@ sub find_wm_window {
 }
 
 sub get_shape {
-	my $self        = shift;
-	my $xid         = shift;
-	my $orig        = shift;
-	my $l_cropped   = shift;
-	my $r_cropped   = shift;
-	my $t_cropped   = shift;
-	my $b_cropped   = shift;
+	my $self 		= shift;
+	my $xid 		= shift;
+	my $orig 		= shift;
+	my $l_cropped 	= shift;
+	my $r_cropped 	= shift;
+	my $t_cropped 	= shift;
+	my $b_cropped 	= shift;
 
 	print "$l_cropped, $r_cropped, $t_cropped, $b_cropped cropped\n" if $self->{_sc}->get_debug;
 
 	print "Calculating window shape\n" if $self->{_sc}->get_debug;
 
-	#check if extenstion is available and use it
-	my ($ordering, @r) = (undef, undef);
-	if($self->{_x11}{ext_shape}){
-		($ordering, @r) = $self->{_x11}->ShapeGetRectangles($self->find_wm_window($xid), 'Bounding');
-	}
+	my ($ordering, @r) = $self->{_x11}->ShapeGetRectangles($self->find_wm_window($xid), 'Bounding');
 	
 	my $manually_shaped = FALSE;
-	#create shape manually when option is set and the shape was not detected automatically
+	#create shape manually when option is set
 	if (scalar @r <= 1 && defined $self->{_auto_shape} && $self->{_auto_shape}){
 		
 		my $shf = Shutter::App::HelperFunctions->new( $self->{_sc} );
@@ -478,14 +492,33 @@ sub get_window_size {
 
 sub update_highlighter {
 	my $self 	= shift;
+	my $x		= shift;
+	my $y		= shift;
+	my $width	= shift;
+	my $height	= shift;
 
+	#two different methods to hide the window before moving it
+	#(to avoid flicker)
+	if (Gtk2->CHECK_VERSION( 2, 12, 0 )) {
+		$self->{_highlighter}->set_opacity(0);	
+	}else{
+		$self->{_highlighter}->hide;	
+	}
+	
 	if(defined $self->{_c}{'cw'}{'gdk_window'} && defined $self->{_c}{'cw'}{'window'}){
 
+		#Place window and resize it
+		$self->{_highlighter}->move($x-3, $y-3);
+		$self->{_highlighter}->resize($width+6, $height+6);
+		
 		#and show highlighter window at current cursor position		
-		$self->{_highlighter}->show_all;
-		$self->{_highlighter}->queue_draw;
+		$self->{_highlighter}->show;
 
-		Gtk2::Gdk->keyboard_grab( $self->{_highlighter}->window, 0, Gtk2->get_current_event_time );
+		if (Gtk2->CHECK_VERSION( 2, 12, 0 )) {
+			$self->{_notifications_timeout} = Glib::Timeout->add (100, sub{
+				$self->{_highlighter}->set_opacity(1);
+			});		
+		}
 	
 		#save last window objects
 		$self->{_c}{'lw'}{'window'} 	= $self->{_c}{'cw'}{'window'};
@@ -640,9 +673,13 @@ sub find_active_window {
 	my $gdk_window = $self->{_gdk_screen}->get_active_window;
 
 	if ( defined $gdk_window ) {
+
 		my $wnck_window = Gnome2::Wnck::Window->get( $gdk_window->get_xid );
+		
 		if ( defined $wnck_window ) {
+						
 			return ($wnck_window, $gdk_window);
+			
 		}		  				
 	}
 	
@@ -708,9 +745,9 @@ sub find_region_for_window_type {
 			$self->{_c}{'cw'}{'is_parent'} 	= FALSE;
 
 			#~ print $self->{_c}{'cw'}{'x'}, " - ",			 			
-			#~ $self->{_c}{'cw'}{'y'}, " - ", 			
-			#~ $self->{_c}{'cw'}{'width'}, " - ", 		
-			#~ $self->{_c}{'cw'}{'height'}, " \n "; 				
+				  #~ $self->{_c}{'cw'}{'y'}, " - ", 			
+				  #~ $self->{_c}{'cw'}{'width'}, " - ", 		
+				  #~ $self->{_c}{'cw'}{'height'}, " \n "; 				
 		}
 	}
 	
@@ -718,14 +755,14 @@ sub find_region_for_window_type {
 }
 
 sub select_window {
-	my $self = shift;
-	my $event = shift;
-	my $active_workspace = shift;
-
+	my $self 				= shift;
+	my $event				= shift;
+	my $active_workspace	= shift;
+	
 	#select child window
-	my $depth = shift; 
-	my $limit = shift;
-	my $type_hint = shift;
+	my $depth				= shift; 
+	my $limit				= shift;
+	my $type_hint			= shift;
 
 	#root window size is minimum at startup
 	$self->{_min_size} = $self->{_root}->{w} * $self->{_root}->{h};
@@ -751,7 +788,12 @@ sub select_window {
 	if ( (Gtk2::Gdk->pointer_is_grabbed && ($self->{_c}{'lw'}{'gdk_window'} ne $self->{_c}{'cw'}{'gdk_window'})) || 
 		 (Gtk2::Gdk->pointer_is_grabbed && $self->{_c}{'ws_init'}) ) {
 			 
-		$self->update_highlighter();
+		$self->update_highlighter(
+			$self->{_c}{'cw'}{'x'},
+			$self->{_c}{'cw'}{'y'},
+			$self->{_c}{'cw'}{'width'},
+			$self->{_c}{'cw'}{'height'}
+		);
 		
 		#reset flag
 		$self->{_c}{'ws_init'} = FALSE;
@@ -780,30 +822,34 @@ sub window {
 	#when mode is section or window 
 	unless($self->{_mode} eq "menu" || $self->{_mode} eq "tray_menu" || $self->{_mode} eq "tooltip" || $self->{_mode} eq "tray_tooltip" || $self->{_mode} eq "awindow" || $self->{_mode} eq "tray_awindow"){
 		
-		$self->{_highlighter}->realize;
-		
 		my $grab_counter = 0;
 		while ( !Gtk2::Gdk->pointer_is_grabbed && $grab_counter < 100 ) {
 			Gtk2::Gdk->pointer_grab(
-				$self->{_root}, FALSE,
-				[qw/pointer-motion-mask button-press-mask button-release-mask/], undef,
+				$self->{_root},
+				0,
+				[   qw/
+						pointer-motion-mask
+						button-press-mask
+						button-release-mask/
+				],
+				undef,
 				Gtk2::Gdk::Cursor->new('GDK_HAND2'),
 				Gtk2->get_current_event_time
 			);
-			Gtk2::Gdk->keyboard_grab( $self->{_highlighter}->window, 0, Gtk2->get_current_event_time );
+			Gtk2::Gdk->keyboard_grab( $self->{_root}, 0, Gtk2->get_current_event_time );
 			$grab_counter++;
 		}
 
 	}
 
 	#init
-	$self->{_c} = ();
-	$self->{_c}{'ws'} = undef;	
-	$self->{_c}{'ws_init'} = FALSE;	
+	$self->{_c} 					= ();
+	$self->{_c}{'ws'} 				= undef;	
+	$self->{_c}{'ws_init'} 			= FALSE;	
 	$self->{_c}{'lw'}{'gdk_window'} = 0;
 
 	#root window size is minimum at startup
-	$self->{_min_size}              = $self->{_root}->{w} * $self->{_root}->{h};
+	$self->{_min_size} 				= $self->{_root}->{w} * $self->{_root}->{h};
 	$self->{_c}{'cw'}{'gdk_window'} = $self->{_root};
 	$self->{_c}{'cw'}{'x'}          = $self->{_root}->{x};
 	$self->{_c}{'cw'}{'y'}          = $self->{_root}->{y};
@@ -834,7 +880,7 @@ sub window {
 				if ( $event->type eq 'key-press' ) {
 					next unless defined $event->keyval;
 					
-					if ( $event->keyval == Gtk2::Gdk->keyval_from_name('Escape') ) {
+					if ( $event->keyval == $Gtk2::Gdk::Keysyms{Escape} ) {
 
 						#destroy highlighter window
 						$self->{_highlighter}->destroy;
@@ -929,7 +975,7 @@ sub window {
 					$output = $output_new;
 												
 					#respect rounded corners of wm decorations (metacity for example - does not work with compiz currently)	
-					if($self->{_include_border}){
+					if($self->{_x11}{ext_shape} && $self->{_include_border}){
 						my $xid = $self->{_c}{ 'cw' }{ 'gdk_window' }->get_xid;
 						#do not try this for child windows
 						foreach my $win ($self->{_wnck_screen}->get_windows){
@@ -1009,11 +1055,11 @@ sub window {
 			
 				$self->{_c}{'cw'}{'window'}     = $wnck_window;
 				$self->{_c}{'cw'}{'gdk_window'} = $gdk_window;
-				$self->{_c}{'cw'}{'x'}          = $xp;
-				$self->{_c}{'cw'}{'y'}          = $yp;
-				$self->{_c}{'cw'}{'width'}      = $wp;
-				$self->{_c}{'cw'}{'height'}     = $hp;
-				$self->{_c}{'cw'}{'is_parent'}  = TRUE;
+				$self->{_c}{'cw'}{'x'} 			= $xp;
+				$self->{_c}{'cw'}{'y'} 			= $yp;
+				$self->{_c}{'cw'}{'width'} 		= $wp;
+				$self->{_c}{'cw'}{'height'} 	= $hp;
+				$self->{_c}{'cw'}{'is_parent'} 	= TRUE;
 			
 			}
 
@@ -1077,7 +1123,7 @@ sub window {
 		#(metacity for example - does not work with compiz currently)
 		#only if toplevel window was selected
 		if ( ( $self->{_mode} eq "window" || $self->{_mode} eq "tray_window" ||  $self->{_mode} eq "awindow"  || $self->{_mode} eq "tray_awindow" ) ) {
-			if($self->{_include_border}){
+			if($self->{_x11}{ext_shape} && $self->{_include_border}){
 				my $xid = $self->{_c}{ 'cw' }{ 'gdk_window' }->get_xid;
 				#do not try this for child windows
 				foreach my $win ($self->{_wnck_screen}->get_windows){
@@ -1228,9 +1274,7 @@ sub redo_capture {
 				$output = $output_new;
 
 				if($self->{_mode} eq "window" || $self->{_mode} eq "tray_window" || $self->{_mode} eq "awindow" || $self->{_mode} eq "tray_awindow"){
-					if($self->{_include_border}){
-						$output = $self->get_shape($gxid, $output, $l_cropped, $r_cropped, $t_cropped, $b_cropped);
-					}
+					$output = $self->get_shape($gxid, $output, $l_cropped, $r_cropped, $t_cropped, $b_cropped);
 				}
 				
 				#restore window size when autoresizing was used
